Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2664)

Unified Diff: chrome/browser/infobars/infobar_container.h

Issue 211273007: Split InfoBarService core code into InfoBarManager (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Rebase + comments Created 6 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/browser/infobars/infobar.cc ('k') | chrome/browser/infobars/infobar_container.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/infobars/infobar_container.h
diff --git a/chrome/browser/infobars/infobar_container.h b/chrome/browser/infobars/infobar_container.h
index c605138b8ef7811b96e720858266d082b48b7bbe..683888a5e3612d32bde51e8376ac313dd6d0d50a 100644
--- a/chrome/browser/infobars/infobar_container.h
+++ b/chrome/browser/infobars/infobar_container.h
@@ -9,19 +9,19 @@
#include "base/compiler_specific.h"
#include "base/time/time.h"
-#include "chrome/browser/infobars/infobar_service.h"
+#include "chrome/browser/infobars/infobar_manager.h"
#include "third_party/skia/include/core/SkColor.h"
class InfoBar;
// InfoBarContainer is a cross-platform base class to handle the visibility-
// related aspects of InfoBars. While InfoBarService owns the InfoBars, the
// InfoBarContainer is responsible for telling particular InfoBars that they
// should be hidden or visible.
//
// Platforms need to subclass this to implement a few platform-specific
// functions, which are pure virtual here.
-class InfoBarContainer : public InfoBarService::Observer {
+class InfoBarContainer : public InfoBarManager::Observer {
public:
class Delegate {
public:
@@ -43,11 +43,11 @@ class InfoBarContainer : public InfoBarService::Observer {
explicit InfoBarContainer(Delegate* delegate);
virtual ~InfoBarContainer();
// Changes the InfoBarService for which this container is showing infobars.
// This will hide all current infobars, remove them from the container, add
// the infobars from |infobar_service|, and show them all. |infobar_service|
// may be NULL.
- void ChangeInfoBarService(InfoBarService* infobar_service);
+ void ChangeInfoBarManager(InfoBarManager* infobar_manager);
// Returns the amount by which to overlap the toolbar above, and, when
// |total_height| is non-NULL, set it to the height of the InfoBarContainer
@@ -99,12 +99,12 @@ class InfoBarContainer : public InfoBarService::Observer {
private:
typedef std::vector<InfoBar*> InfoBars;
- // InfoBarService::Observer:
+ // InfoBarManager::Observer:
virtual void OnInfoBarAdded(InfoBar* infobar) OVERRIDE;
virtual void OnInfoBarRemoved(InfoBar* infobar, bool animate) OVERRIDE;
virtual void OnInfoBarReplaced(InfoBar* old_infobar,
InfoBar* new_infobar) OVERRIDE;
- virtual void OnServiceShuttingDown(InfoBarService* service) OVERRIDE;
+ virtual void OnManagerShuttingDown(InfoBarManager* manager) OVERRIDE;
// Adds |infobar| to this container before the existing infobar at position
// |position| and calls Show() on it. |animate| is passed along to
@@ -121,7 +121,7 @@ class InfoBarContainer : public InfoBarService::Observer {
int ArrowTargetHeightForInfoBar(size_t infobar_index) const;
Delegate* delegate_;
- InfoBarService* infobar_service_;
+ InfoBarManager* infobar_manager_;
InfoBars infobars_;
// Calculated in SetMaxTopArrowHeight().
« no previous file with comments | « chrome/browser/infobars/infobar.cc ('k') | chrome/browser/infobars/infobar_container.cc » ('j') | no next file with comments »
@@ -9,19 +9,19 @@
class InfoBar;
// InfoBarContainer is a cross-platform base class to handle the visibility-
-// related aspects of InfoBars. While InfoBarService owns the InfoBars, the
+// related aspects of InfoBars. While InfoBarManager owns the InfoBars, the
// InfoBarContainer is responsible for telling particular InfoBars that they
// should be hidden or visible.
@@ -43,11 +43,11 @@ class InfoBarContainer : public InfoBarService::Observer {
explicit InfoBarContainer(Delegate* delegate);
virtual ~InfoBarContainer();
- // Changes the InfoBarService for which this container is showing infobars.
+ // Changes the InfoBarManager for which this container is showing infobars.
// This will hide all current infobars, remove them from the container, add
@@ -43,11 +43,11 @@ class InfoBarContainer : public InfoBarService::Observer {
// This will hide all current infobars, remove them from the container, add
- // the infobars from |infobar_service|, and show them all. |infobar_service|
+ // the infobars from |infobar_manager|, and show them all. |infobar_manager|
// may be NULL.

Powered by Google App Engine
This is Rietveld 408576698